vfbLib.vfb.entry.VfbEntry
=========================

.. currentmodule:: vfbLib.vfb.entry

.. autoclass:: VfbEntry
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VfbEntry.__init__
      ~VfbEntry.as_dict
      ~VfbEntry.compile
      ~VfbEntry.decompile
      ~VfbEntry.merge_masters_data
      ~VfbEntry.read
      ~VfbEntry.read_double
      ~VfbEntry.read_doubles
      ~VfbEntry.read_float
      ~VfbEntry.read_floats
      ~VfbEntry.read_int16
      ~VfbEntry.read_int32
      ~VfbEntry.read_int8
      ~VfbEntry.read_str
      ~VfbEntry.read_str_all
      ~VfbEntry.read_uint16
      ~VfbEntry.read_uint32
      ~VfbEntry.read_uint8
      ~VfbEntry.read_value
      ~VfbEntry.store_hash
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VfbEntry.current_hash
      ~VfbEntry.data
      ~VfbEntry.decompiled
      ~VfbEntry.encoding
      ~VfbEntry.header
      ~VfbEntry.id
      ~VfbEntry.modified
      ~VfbEntry.size
      ~VfbEntry.stream
   
   